@@ -1,4 +1,4 @@
-from .gs_global import global_context
+from .gs_global import global_context,set_mongo_connection_object,set_i18n_required_flag
 from .pre_handler import get_context
 from .menu_handler import activate_menu
 from .menu_handler import handle_active_menu
